@@ -1,6 +1,14 @@
+#' Get attribute nextPageLink
+#' @noRd
+get_attr_nextpagetoken <- function(x){
+  attr(x, "nextPageToken")
+}
+
+
 #' if argument is NULL, no line output
 #'
 #' @keywords internal
+#' @noRd
 cat0 <- function(prefix = "", x){
   if(!is.null(x)){
     cat(prefix, x, "\n")
@@ -10,6 +18,7 @@ cat0 <- function(prefix = "", x){
 #' Javascript time to R time
 #'
 #' @keywords internal
+#' @noRd
 js_to_posix <- function(x){
   as.POSIXct(as.numeric(x) / 1000, origin = "1970-01-01")
 }
@@ -17,6 +26,7 @@ js_to_posix <- function(x){
 #' taken from utils:::format.object_size
 #'
 #' @keywords internal
+#' @noRd
 format_object_size <- function (x, units = "b", ...)
 {
   units <- match.arg(units, c("b", "auto", "Kb", "Mb", "Gb",
@@ -46,6 +56,7 @@ format_object_size <- function (x, units = "b", ...)
 
 #' Timestamp to R date
 #' @keywords internal
+#' @noRd
 timestamp_to_r <- function(t){
   as.POSIXct(t, format = "%Y-%m-%dT%H:%M:%S")
 }
@@ -55,11 +66,13 @@ timestamp_to_r <- function(t){
 #' a list of NULLs
 #'
 #' @keywords internal
+#' @noRd
 is.NullOb <- function(x) is.null(x) | all(sapply(x, is.null))
 
 #' Recursively step down into list, removing all such objects
 #'
 #' @keywords internal
+#' @noRd
 rmNullObs <- function(x) {
   x <- Filter(Negate(is.NullOb), x)
   lapply(x, function(x) if (is.list(x)) rmNullObs(x) else x)
@@ -74,6 +87,7 @@ rmNullObs <- function(x) {
 #' @return Boolean
 #' 
 #' @keywords internal
+#' @noRd
 is.error <- function(test_me){
   inherits(test_me, "try-error")
 }
@@ -85,6 +99,7 @@ is.error <- function(test_me){
 #' @return The error message
 #'
 #' @keywords internal
+#' @noRd
 error.message <- function(test_me){
   if(is.error(test_me)) attr(test_me, "condition")$message
 }
@@ -96,6 +111,7 @@ error.message <- function(test_me){
 #'
 #' @details 0 = everything, 1 = debug, 2=normal, 3=important
 #' @keywords internal
+#' @noRd
 myMessage <- function(..., level = 1){
   
   
@@ -116,6 +132,7 @@ myMessage <- function(..., level = 1){
 #'
 #' @return A random 15 digit hash
 #' @keywords internal
+#' @noRd
 idempotency <- function(){
   set.seed(Sys.time())
   paste(sample(c(LETTERS, letters, 0:9), 15, TRUE),collapse="")
